/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block;

import mmcorej.CMMCore;
import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.interface_.PluginBundled;
import org.bioimageanalysis.icy.extension.plugin.interface_.PluginLibrary;
import org.bioimageanalysis.icy.gui.dialog.MessageDialog;
import org.jetbrains.annotations.Nullable;
import org.micromanager.utils.ReportingUtils;
import plugins.adufour.blocks.lang.Block;
import plugins.tprovoost.Microscopy.MicroManager.MicroManager;
import plugins.tprovoost.Microscopy.MicroManagerForIcy.MicromanagerPlugin;

/**
 * @author Stephane Dallongeville
 */
public abstract class AbstractMicroscopeBlock extends Plugin implements Block, PluginLibrary, PluginBundled {
    public AbstractMicroscopeBlock() {
        super();

        MicromanagerPlugin.init();

        if (!MicroManager.isInitialized())
            throw new RuntimeException("Cannot initialize Micro-Manager !");
    }

    @Override
    public String getMainPluginClassName() {
        return MicroscopyBlocks.class.getName();
    }

    public static @Nullable CMMCore getMMCore(final boolean throwException) {
        try {
            return MicroManager.getCore();
        }
        catch (final Throwable e) {
            ReportingUtils.logError(e);
            if (throwException)
                throw new RuntimeException("Cannot retrieve Micro-Manager core !", e);

            MessageDialog.showDialog("Cannot find Micro-Manager...",
                    "You need to start Micro-Manager plugin before using Micro-Manager blocks !",
                    MessageDialog.WARNING_MESSAGE);

            // throw new VarException(null,
            // "Cannot retrieve Micro-Manager core...\nBe sure you started Micro-Manager plugin
            // before using Micro-Manager blocks !");
        }

        return null;
    }
}
