/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.capture;

import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import org.json.JSONObject;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarInteger;
import plugins.stef.micromanager.block.AbstractMicroscopeBlock;
import plugins.tprovoost.Microscopy.MicroManager.MicroManager;

/**
 * Retrieve global acquisition metadata and last acquired image metadata (Micro-Manager)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Get Micro-Manager Metadata")
@IcyPluginIcon(path = "/mm_blocks.png")
public class MicroscopeGetMetadata extends AbstractMicroscopeBlock {
    VarInteger channel = new VarInteger("Channel", 0);
    Var<JSONObject> metadata = new Var<>("Image metadata", JSONObject.class);
    Var<JSONObject> acqMetadata = new Var<>("Acquisition metadata", JSONObject.class);

    @Override
    public void run() {
        metadata.setValue(MicroManager.getMetadata(channel.getValue()));
        acqMetadata.setValue(MicroManager.getAcquisitionMetaData());
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("channel", channel);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("imageMetadata", metadata);
        outputMap.add("acqMetadata", acqMetadata);
    }
}
