/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.capture;

import mmcorej.TaggedImage;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarArray;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;
import plugins.stef.micromanager.block.AbstractMicroscopeBlock;
import plugins.tprovoost.Microscopy.MicroManager.tools.MMUtils;

/**
 * Set a TaggedImage into a Sequence (Micro-Manager)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Set Tagged Image(s)")
@IcyPluginIcon(path = "/mm_blocks.png")
public class MicroscopeSetTaggedImage extends AbstractMicroscopeBlock {
    VarArray<TaggedImage> taggedImages = new VarArray<>("Tagged image(s)", TaggedImage[].class, new TaggedImage[0]);
    VarSequence seq = new VarSequence("Sequence", null);
    VarInteger posT = new VarInteger("T", -1);
    VarInteger posZ = new VarInteger("Z", -1);
    VarInteger posC = new VarInteger("C", -1);
    VarInteger sizeT = new VarInteger("Size T", -1);
    VarInteger sizeZ = new VarInteger("Size Z", -1);
    VarInteger sizeC = new VarInteger("Size C", -1);

    @Override
    public void run() {
        try {
            for (final TaggedImage image : taggedImages.getValue()) {
                // set image position metadata
                MMUtils.setImageMetadata(
                        image,
                        posT.getValue(),
                        posZ.getValue(),
                        posC.getValue(),
                        sizeT.getValue(),
                        sizeZ.getValue(),
                        sizeC.getValue()
                );
                // store image in sequence
                MMUtils.setImage(seq.getValue(), image);
            }
        }
        catch (final Throwable t) {
            throw new VarException(taggedImages, t.getMessage());
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("taggedImage", taggedImages);
        inputMap.add("seq", seq);
        inputMap.add("t", posT);
        inputMap.add("z", posZ);
        inputMap.add("c", posC);
        inputMap.add("sizeT", sizeT);
        inputMap.add("sizeZ", sizeZ);
        inputMap.add("sizeC", sizeC);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        //
    }
}
