/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.capture;

import mmcorej.TaggedImage;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarArray;
import plugins.adufour.vars.lang.VarObject;
import plugins.adufour.vars.util.VarException;
import plugins.stef.micromanager.block.AbstractMicroscopeBlock;
import plugins.tprovoost.Microscopy.MicroManager.MicroManager;

import java.util.List;

/**
 * Snap single channel image (Micro-Manager)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Snap Image")
@IcyPluginIcon(path = "/mm_blocks.png")
public class MicroscopeSnapImage extends AbstractMicroscopeBlock {
    VarArray<TaggedImage> out = new VarArray<>("Tagged image(s)", TaggedImage[].class, new TaggedImage[0]);
    VarObject trigger = new VarObject("Trigger", null);

    @Override
    public void run() {
        try {
            final List<TaggedImage> images = MicroManager.snapTaggedImage();
            if (images.isEmpty())
                throw new Exception("Cannot snap image from Micro-Manager !");

            out.setValue(images.toArray(new TaggedImage[0]));
        }
        catch (final Throwable t) {
            throw new VarException(out, t.getMessage());
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("trigger", trigger);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("out", out);
    }
}
