/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.lang;

import org.bioimageanalysis.icy.common.collection.CollectionUtil;
import org.micromanager.utils.ChannelSpec;
import plugins.adufour.vars.gui.VarEditor;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarArray;
import plugins.adufour.vars.util.VarListener;

/**
 * Class in standby until an EzPlug fix
 */
public class VarChannels extends VarArray<ChannelSpec> {
    VarChannelsEditor editor;

    public VarChannels(final String name, final VarMMGroup groupVar) {
        super(name, ChannelSpec[].class, null);

        // can be initialized by super constructor
        if (editor == null)
            editor = new VarChannelsEditor(this);

        setGroup(groupVar.getValue());

        groupVar.addListener(new VarListener<>() {
            @Override
            public void valueChanged(final Var<String> source, final String oldValue, final String newValue) {
                setGroup(newValue);
            }

            @Override
            public void referenceChanged(final Var<String> source, final Var<? extends String> oldReference, final Var<? extends String> newReference) {
                //
            }
        });
    }

    public VarChannels(final VarMMGroup groupVar) {
        this("Channels", groupVar);
    }

    @Override
    public VarEditor<ChannelSpec[]> createVarEditor() {
        if (editor == null)
            editor = new VarChannelsEditor(this);

        return editor;
    }

    @Override
    public ChannelSpec[] getValue() {
        return editor.table.getChannels().toArray(new ChannelSpec[0]);
    }

    @Override
    public void setValue(final ChannelSpec[] value) {
        editor.table.setChannels(CollectionUtil.asArrayList(value));
    }

    public void setGroup(final String groupName) {
        editor.setGroup(groupName);
    }
}
