/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.lang;

import org.jetbrains.annotations.NotNull;
import plugins.adufour.vars.gui.model.ValueSelectionModel;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarString;
import plugins.adufour.vars.util.VarListener;
import plugins.tprovoost.Microscopy.MicroManager.MicroManager;

import java.util.List;

/**
 * EzVar representing Micro-Manager config preset.
 *
 * @author Stephane Dallongeville
 */
public class VarMMPreset extends VarString {
    public VarMMPreset(final String name, final @NotNull VarMMGroup groupVar) {
        super(name, "");

        // set values
        refreshPresets(groupVar.getValue());

        // listen group var change
        groupVar.addListener(new VarListener<>() {
            @Override
            public void valueChanged(final Var<String> source, final String oldValue, final String newValue) {
                refreshPresets(newValue);
            }

            @Override
            public void referenceChanged(final Var<String> source, final Var<? extends String> oldReference, final Var<? extends String> newReference) {
                //
            }
        });
    }

    public VarMMPreset(final VarMMGroup groupVar) {
        this("Preset", groupVar);
    }

    public void refreshPresets(final String group) {
        final List<String> presets = MicroManager.getConfigs(group);

        if (!presets.isEmpty())
            setDefaultEditorModel(new ValueSelectionModel<>(presets.toArray(new String[0]), presets.getFirst(), false));
        else
            setDefaultEditorModel(new ValueSelectionModel<>(new String[]{""}, "", false));
    }
}
