/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.lang;

import org.jetbrains.annotations.Contract;
import org.micromanager.api.MultiStagePosition;
import plugins.adufour.vars.gui.VarEditor;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarArray;
import plugins.tprovoost.Microscopy.MicroManager.MicroManager;

import javax.swing.*;
import java.awt.*;
import java.util.Objects;

public class VarMultiStagePosition extends VarArray<MultiStagePosition> {
    VarEditorMultiStagePositions pos;

    public VarMultiStagePosition(final String name, final MultiStagePosition[] defaultValue) {
        super(name, MultiStagePosition[].class, defaultValue);

        // can be initialized with super constructor
        if (pos == null)
            pos = new VarEditorMultiStagePositions(this);
    }

    @Override
    public VarEditor<MultiStagePosition[]> createVarEditor() {
        if (pos == null)
            pos = new VarEditorMultiStagePositions(this);

        return pos;
    }

    private static class VarEditorMultiStagePositions extends VarEditor<MultiStagePosition[]> {
        JButton btnOpen;

        public VarEditorMultiStagePositions(final Var<MultiStagePosition[]> variable) {
            super(variable);
        }

        @Override
        protected JComponent createEditorComponent() {
            btnOpen = new JButton("Open");
            btnOpen.addActionListener(e -> Objects.requireNonNull(MicroManager.getMMStudio()).showXYPositionList());

            return btnOpen;
        }

        @Contract(pure = true)
        @Override
        protected void activateListeners() {
        }

        @Contract(pure = true)
        @Override
        protected void deactivateListeners() {
        }

        @Contract(pure = true)
        @Override
        protected void updateInterfaceValue() {
        }

        @Override
        public Dimension getPreferredSize() {
            if (btnOpen != null)
                return btnOpen.getPreferredSize();

            return new Dimension(100, 24);
        }

        @Override
        public void setComponentToolTipText(final String s) {
            if (btnOpen != null)
                btnOpen.setToolTipText(s);
        }

        @Override
        protected void setEditorEnabled(final boolean enabled) {
            if (btnOpen != null)
                btnOpen.setEnabled(enabled);
        }
    }
}
