/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.setting;

import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarDouble;
import plugins.adufour.vars.lang.VarObject;
import plugins.adufour.vars.util.VarException;
import plugins.stef.micromanager.block.AbstractMicroscopeBlock;
import plugins.tprovoost.Microscopy.MicroManager.MicroManager;

/**
 * Return camera exposure value in ms (Micro-Manager)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Get Micro-Manager Exposure")
@IcyPluginIcon(path = "/mm_blocks.png")
public class MicroscopeGetExposure extends AbstractMicroscopeBlock {
    VarObject trigger = new VarObject("Trigger", null);
    VarDouble exposure = new VarDouble("Exposure (ms)", 50d);

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("trigger", trigger);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("exposure", exposure);
    }

    @Override
    public void run() {
        try {
            exposure.setValue(MicroManager.getExposure());
        }
        catch (final Throwable t) {
            throw new VarException(exposure, t.getMessage());
        }
    }
}
