/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.setting;

import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import org.micromanager.MMStudio;
import org.micromanager.api.MultiStagePosition;
import org.micromanager.api.PositionList;
import plugins.adufour.blocks.tools.input.InputBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarArray;
import plugins.adufour.vars.util.VarException;
import plugins.stef.micromanager.block.AbstractMicroscopeBlock;
import plugins.stef.micromanager.block.lang.VarMultiStagePosition;
import plugins.tprovoost.Microscopy.MicroManager.MicroManager;

/**
 * Define a list of stage positions (Micro-Manager)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Set Micro-Manager Stage Positions")
@IcyPluginIcon(path = "/mm_blocks.png")
public class MicroscopePositions extends AbstractMicroscopeBlock implements InputBlock {
    VarArray<MultiStagePosition> varPositions;

    public MicroscopePositions() {
        super();

        varPositions = new VarMultiStagePosition("Positions", null);
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("positions", varPositions);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        //
    }

    @Override
    public void run() {
        final MMStudio mstudio = MicroManager.getMMStudio();
        if (mstudio == null)
            throw new VarException(null, "Cannot retrieve Micro-Manager core...\nBe sure you started Micro-Manager plugin before using Micro-Manager blocks !");

        try {
            final PositionList list = mstudio.getPositionList();

            if (list.getPositions() == null)
                throw new VarException(varPositions, "PositionList is empty. There should be at least one value.");

            varPositions.setValue(list.getPositions());
        }
        catch (final Exception e) {
            throw new VarException(varPositions, e.getMessage());
        }
    }
}
