/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.setting;

import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarBoolean;
import plugins.adufour.vars.lang.VarObject;
import plugins.adufour.vars.util.VarException;
import plugins.stef.micromanager.block.AbstractMicroscopeBlock;
import plugins.tprovoost.Microscopy.MicroManager.MicroManager;

/**
 * Set the shutter position: open / close (Micro-Manager)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Set Micro-Manager Shutter")
@IcyPluginIcon(path = "/mm_blocks.png")
public class MicroscopeSetShutter extends AbstractMicroscopeBlock {
    VarObject trigger = new VarObject("Trigger", null);
    VarBoolean open = new VarBoolean("Open", true);
    VarBoolean done = new VarBoolean("Done", false);

    @Override
    public void run() {
        done.setValue(Boolean.FALSE);

        try {
            MicroManager.setShutterOpen(open.getValue());
            done.setValue(Boolean.TRUE);
        }
        catch (final Throwable t) {
            throw new VarException(open, t.getMessage());
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("trigger", trigger);
        inputMap.add("open", open);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("done", done);
    }
}
