/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.stage;

import org.bioimageanalysis.icy.common.geom.point.Point3D;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarBoolean;
import plugins.adufour.vars.lang.VarDouble;
import plugins.adufour.vars.lang.VarObject;
import plugins.adufour.vars.util.VarException;
import plugins.stef.micromanager.block.AbstractMicroscopeBlock;
import plugins.tprovoost.Microscopy.MicroManager.tools.StageMover;

/**
 * Return the stage XYZ position (Micro-Manager)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Get Micro-Manager Stage XYZ")
@IcyPluginIcon(path = "/mm_blocks.png")
public class MicroscopeGetStageXYZ extends AbstractMicroscopeBlock {
    VarObject trigger = new VarObject("Trigger", null);
    VarBoolean wait = new VarBoolean("Wait stage", true);
    VarDouble outX = new VarDouble("X", 0d);
    VarDouble outY = new VarDouble("Y", 0d);
    VarDouble outZ = new VarDouble("Z", 0d);

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("trigger", trigger);
        inputMap.add("wait", wait);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("x", outX);
        outputMap.add("y", outY);
        outputMap.add("z", outZ);
    }

    @Override
    public void run() {
        try {
            final Point3D.Double pos = StageMover.getXYZ();
            outX.setValue(Double.valueOf(pos.x));
            outY.setValue(Double.valueOf(pos.y));
            outZ.setValue(Double.valueOf(pos.z));
        }
        catch (final Throwable t) {
            throw new VarException(outX, t.getMessage());
        }
    }
}
