/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.stef.micromanager.block.tool;

import mmcorej.TaggedImage;
import org.bioimageanalysis.icy.common.collection.CollectionUtil;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.image.IcyBufferedImage;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarArray;
import plugins.adufour.vars.util.VarException;
import plugins.stef.micromanager.block.AbstractMicroscopeBlock;
import plugins.tprovoost.Microscopy.MicroManager.tools.MMUtils;

/**
 * Block to convert a TaggedImage to an IcyBufferedImage (Micro-Manager)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("TaggedImage to IcyBufferedImage")
@IcyPluginIcon(path = "/mm_blocks.png")
public class TaggedImageToIcyImage extends AbstractMicroscopeBlock {
    VarArray<TaggedImage> in = new VarArray<>("Tagged Image", TaggedImage[].class, new TaggedImage[0]);
    Var<IcyBufferedImage> out = new Var<>("Icy Image", IcyBufferedImage.class);

    @Override
    public void run() {
        try {
            out.setValue(MMUtils.convertToIcyImage(CollectionUtil.asList(in.getValue())));
        }
        catch (final Throwable t) {
            throw new VarException(out, t.getMessage());
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("taggedImage", in);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("icyImage", out);
    }
}